@@ -573,9 +573,9 @@ void Editor::formatScalesAsStitches()
 }
 
 
-void Editor::formatScalesAsCM()
+void Editor::formatScalesAsCentimeters()
 {
-    m_formatScalesAs = Configuration::EnumEditor_FormatScalesAs::CM;
+    m_formatScalesAs = Configuration::EnumEditor_FormatScalesAs::Centimeters;
     m_horizontalScale->setUnits(m_formatScalesAs);
     m_verticalScale->setUnits(m_formatScalesAs);
 }
@@ -1123,6 +1123,8 @@ void Editor::toolInitText()
             delete m_pastePattern;
             m_pastePattern = nullptr;
         }
+    } else { // dialog was cancelled, reset tool to paint
+        topLevelWidget()->findChild<QAction *>(QStringLiteral("toolPaint"))->trigger();
     }
 }
 
@@ -1354,7 +1356,9 @@ void Editor::renderBackgroundImages(QPainter &painter, const QRect &updateRectan
 
         if (backgroundImage->isVisible()) {
             if (backgroundImage->location().intersects(updateRectangle)) {
+                painter.setClipRect(updateRectangle.x(), updateRectangle.y(), updateRectangle.width(), updateRectangle.height());
                 painter.drawImage(backgroundImage->location(), backgroundImage->image());
+                painter.setClipping(false);
             }
         }
     }
